import Player from "./Player.js";
import { Sushi } from "./Ressources.js";
import { io } from "socket.io-client";

const Main = (playerName, playerCharacter) => {
  const canvas = document.querySelector(".map");
  const ctx = canvas.getContext("2d");

  canvas.width = document.documentElement.clientWidth;
  canvas.height = document.documentElement.clientHeight;
  ctx.width = 6000;
  ctx.height = 3340;
  const xStart = canvas.width / 2;
  const xEnd = ctx.width - canvas.width / 2;
  const yStart = canvas.height / 2;
  const yEnd = ctx.height - canvas.height / 2;

  window.addEventListener("resize", (e) => {
    e.preventDefault();
    canvas.width = document.documentElement.clientWidth;
    canvas.height = document.documentElement.clientHeight;
  });

  const backgroundImage = new Image();
  backgroundImage.src = "/images/map.jpg";

  document.addEventListener("keydown", (event) => {
    event.preventDefault();
    // Mettre à jour la direction en fonction des touches enfoncées
    switch (event.keyCode) {
      case 37: // Gauche
        player.direction.x = -1;
        break;
      case 38: // Haut
        player.direction.y = -1;
        break;
      case 39: // Droite
        player.direction.x = 1;
        break;
      case 40: // Bas
        player.direction.y = 1;
        break;
    }
  });

  document.addEventListener("keyup", (event) => {
    event.preventDefault();
    // Mettre à jour la direction en fonction des touches relâchées
    switch (event.keyCode) {
      case 37: // Gauche
        if (player.direction.x < 0) {
          player.direction.x = 0;
        }
        break;
      case 38: // Haut
        if (player.direction.y < 0) {
          player.direction.y = 0;
        }
        break;
      case 39: // Droite
        if (player.direction.x > 0) {
          player.direction.x = 0;
        }
        break;
      case 40: // Bas
        if (player.direction.y > 0) {
          player.direction.y = 0;
        }
        break;
    }
  });

  const socket = io();

  let sushis = [];
  socket.on("sushis", (data) => {
    for (let i = 0; i < data?.length; i++) {
      const sushi = new Sushi(
        data[i].x * (xEnd - xStart) + xStart,
        data[i].y * (-yStart + yEnd) + yStart,
        5
      );
      sushis.push(sushi);
    }
  });

  let folder = playerCharacter;
  let userId;

  function getUserId() {
    return new Promise((resolve, reject) => {
      socket.on("user", (data) => {
        userId = data;
        resolve(userId);
      });
    });
  }

  async function myFunction() {
    try {
      const userId = await getUserId();
      const player = new Player(
        Math.random() * (xEnd - xStart) + xStart,
        Math.random() * (-yStart + yEnd) + yStart,
        20,
        folder,
        userId,
        1
      );

      socket.emit("newUser", player);

      let allUsers = [];
      socket.on("allUsers", (datas) => {
        allUsers = datas;
      });

      socket.on("newSushi", (data) => {
        console.log(sushis[data.drop]);
        sushis.splice(data.drop, 1);
        sushis.push(
          new Sushi(
            data.new.x * (xEnd - xStart) + xStart,
            data.new.y * (-yStart + yEnd) + yStart,
            5
          )
        );
      });

      let mouseX;
      let mouseY;

      canvas.addEventListener("mousemove", (event) => {
        event.preventDefault();
        mouseX = event.clientX;
        mouseY = event.clientY;

        player.moveTo(mouseX, mouseY, canvas);
      });

      function update() {
        ctx.save();
        ctx.clearRect(0, 0, ctx.width, ctx.height);
        ctx.beginPath();
        const cameraX = canvas.width / 2 - player.x;
        const cameraY = canvas.height / 2 - player.y;
        ctx.translate(cameraX, cameraY);
        ctx.drawImage(backgroundImage, 0, 0, ctx.width, ctx.height);
        sushis.forEach((sushi) => {
          sushi.draw(ctx);
        });
        allUsers.forEach((user) => {
          const otherPlayer = new Player(
            user.x,
            user.y,
            user.radius,
            user.imageFolder,
            user.id,
            user.imageId
          );
          otherPlayer.draw(ctx);
        });
        player.eatSushi(sushis, socket);
        player.move(ctx, mouseX, mouseY);
        ctx.restore();
        socket.emit("updateUser", player);
        requestAnimationFrame(update);
      }
      update();
    } catch (error) {
      console.error(error);
    }
  }
  myFunction();
};

export default Main;
